function Work(C,N,MOD)
% WORK: Slave for computing pi using MPITB
%
%	Work ( C, N, MOD )
%
%  C	#computers used (NOT including this one)
%  N	#subdivisions of the [0, 1] interval
%  MOD	communication primitive:  (s)end (r)educe
%
% computed area is sent to the master
% implicit parameter: MPI rank
%  from 1 (1st slave) to C (last slave)
% [0, 1] is divided in N subdivisions
% each rank computes areas with index congruent with rank-1 modulus C
% rank -> subdivisions computed
% 1	  0  C   2C   3C  ...
% 2	  1  C+1 2C+1 3C+1...
% ...	  . .... .... ....
% C	C-1 2C-1 3C-1 4C-1...
%

TAG=7;
global NEWORLD	% intracommunicator to parent (inherited from startup_slave)
%MPI_Barrier(NEWORLD);			% initial Synch
 NULL=[];
 MPI_Send(NULL,0,TAG,NEWORLD);
 MPI_Recv(NULL,0,TAG,NEWORLD);
[info rank]=MPI_Comm_rank(NEWORLD);	% rank in intracomm = 1..C

%%%%%%%%%%%%%%%
% Computation %
%%%%%%%%%%%%%%%
  width=1/N; lsum=0;			% vectorized code, equivalent to
  i=rank-1:C:N-1;			% for i=rank-1:C:N-1
  x=(i+0.5)*width;			%   x=(i+0.5)*width;
  lsum=sum(4./(1+x.^2));		%   lsum=lsum+4/(1+x^2);
					% end
switch MOD
  case 'r',		dum=0;
keyboard
	MPI_Reduce(lsum,dum,'SUM',0,NEWORLD);	% master = (0 in NEWORLD)
  case 's'
	MPI_Send(lsum,0,TAG,NEWORLD);
end

